@@ -19,7 +19,7 @@ import uuid
 from aiohomekit.exceptions import AlreadyPairedError
 from aiohomekit.model.feature_flags import FeatureFlags
 from aiohomekit.protocol import perform_pair_setup_part1, perform_pair_setup_part2
-from aiohomekit.protocol.statuscodes import HapStatusCodes
+from aiohomekit.protocol.statuscodes import to_status_code
 
 from .connection import HomeKitConnection
 from .pairing import IpPairing
@@ -122,12 +122,12 @@ class IpDiscovery:
         if not response:
             return True
 
-        code = response["code"]
+        code = to_status_code(response["code"])
 
         raise AlreadyPairedError(
             "Identify failed because: {reason} ({code}).".format(
-                reason=HapStatusCodes[code],
-                code=code,
+                reason=code.description,
+                code=code.value,
             )
         )
 
